@@ -1,3 +1,6 @@
+# Version
+from ._version      import __version__
+# Libraries
 from .base58        import Base58Decoder, Base58Encoder, Base58ChecksumError
 from .bech32        import Bech32Decoder, Bech32Encoder, Bech32ChecksumError, Bech32FormatError
 from .wif           import WifDecoder, WifEncoder
@@ -6,7 +9,7 @@ from .P2SH          import P2SH
 from .P2WPKH        import P2WPKH
 from .eth_addr      import EthAddr
 from .xrp_addr      import XrpAddr
-from .bip39         import Bip39MnemonicGenerator, Bip39MnemonicValidator, Bip39SeedGenerator, Bip39ChecksumError
+from .bip39         import EntropyGenerator, Bip39MnemonicGenerator, Bip39MnemonicValidator, Bip39SeedGenerator, Bip39ChecksumError
 from .bip32         import Bip32Const, Bip32, PathParser, Bip32KeyError, Bip32PathError
 from .bip44_base    import Bip44Changes, Bip44Coins, Bip44PrivKeyTypes, Bip44PubKeyTypes, Bip44DepthError
 from .bip44         import Bip44
