@@ -30,9 +30,20 @@ from .bip44_coin_helper import *
 class Bip44Const:
     """ Class container for BIP44 constants. """
 
+    # Specification name
+    SPEC_NAME = "BIP-0044"
     # Purpose
-    PURPOSE = Bip32.HardenIndex(44)
-
+    PURPOSE   = Bip32.HardenIndex(44)
+    # Allowed coins
+    ALLOWED_COINS = \
+        [
+            Bip44Coins.BITCOIN , Bip44Coins.BITCOIN_TESTNET ,
+            Bip44Coins.LITECOIN, Bip44Coins.LITECOIN_TESTNET,
+            Bip44Coins.DOGECOIN, Bip44Coins.DOGECOIN_TESTNET,
+            Bip44Coins.DASH    , Bip44Coins.DASH_TESTNET,
+            Bip44Coins.ETHEREUM,
+            Bip44Coins.RIPPLE,
+        ]
     # Map from Bip44Coins to helper classes
     COIN_TO_HELPER = \
         {
@@ -84,7 +95,7 @@ class Bip44(Bip44Base):
         """
         return self._AccountGeneric(self, acc_idx)
 
-    def Change(self, chain_idx):
+    def Change(self, change_idx):
         """ Derive a child key from the specified account index and return a new Bip object (e.g. BIP44, BIP49, BIP84).
         It calls the underlying _ChangeGeneric method with the current object as parameter.
         TypeError is raised if chain type is not a Bip44Changes enum.
@@ -92,12 +103,12 @@ class Bip44(Bip44Base):
         Bip32KeyError is raised (by Bip32) if the change results in an invalid key.
 
         Args:
-            chain_idx (Bip44Changes) : chain index, must a Bip44Changes enum
+            change_idx (Bip44Changes) : change index, must a Bip44Changes enum
 
         Returns (Bip object):
             Bip object
         """
-        return self._ChangeGeneric(self, chain_idx)
+        return self._ChangeGeneric(self, change_idx)
 
     def AddressIndex(self, addr_idx):
         """ Derive a child key from the specified account index and return a new Bip object (e.g. BIP44, BIP49, BIP84).
@@ -113,6 +124,31 @@ class Bip44(Bip44Base):
         """
         return self._AddressIndexGeneric(self, addr_idx)
 
+    @staticmethod
+    def SpecName():
+        """ Get specification name
+
+        Returns (str):
+            Specification name
+        """
+        return Bip44Const.SPEC_NAME
+
+    @staticmethod
+    def IsCoinAllowed(coin_idx):
+        """ Get if the specified coin is allowed.
+        TypeError is raised if coin_idx is not of Bip44Coins enum.
+
+        Args:
+            coin_idx (Bip44Coins) : coin index, must be a Bip44Coins enum
+
+        Returns (bool):
+            True if allowed, false otherwise
+        """
+        if not isinstance(coin_idx, Bip44Coins):
+            raise TypeError("Coin index is not an enumerative of Bip44Coins")
+
+        return coin_idx in Bip44Const.ALLOWED_COINS
+
     @staticmethod
     def _GetPurpose():
         """ Get purpose.
@@ -168,4 +204,16 @@ class Bip44(Bip44Base):
         Returns (dict or None):
             WIF net versions (main net at key "main", test net at key "test"), None if not supported
         """
-        return Bip44Const.COIN_TO_HELPER[coin_idx].GetWifNetVersions()
+        return Bip44Const.COIN_TO_HELPER[coin_idx].GetConfig().WIF_NET_VER
+
+    @staticmethod
+    def _GetCoinNames(coin_idx):
+        """ Get coin names.
+
+        Args:
+            coin_idx (Bip44Coins) : coin index, must be a Bip44Coins enum
+
+        Returns (dict):
+            Coin names (name at key "name", abbreviation at key "abbr")
+        """
+        return Bip44Const.COIN_TO_HELPER[coin_idx].GetConfig().NAMES
