@@ -52,13 +52,13 @@ class BitcoinHelper:
         return BitcoinHelper.TEST_NET_VER
 
     @staticmethod
-    def GetWifNetVersions():
-        """ Get WIF net versions.
+    def GetConfig():
+        """ Get coin configuration.
 
-        Returns (dict or None):
-            WIF net versions (main net at key "main", test net at key "test"), None if not supported
+        Returns (BitcoinConf):
+            Coin configuration.
         """
-        return BitcoinConf.WIF_NET_VER
+        return BitcoinConf
 
     @staticmethod
     def ComputeAddress(pub_key, is_testnet = False):
@@ -104,13 +104,13 @@ class LitecoinHelper:
         return LitecoinHelper.TEST_NET_VER
 
     @staticmethod
-    def GetWifNetVersions():
-        """ Get WIF net versions.
+    def GetConfig():
+        """ Get coin configuration.
 
-        Returns (dict or None):
-            WIF net versions (main net at key "main", test net at key "test"), None if not supported
+        Returns (LitecoinConf):
+            Coin configuration.
         """
-        return LitecoinConf.WIF_NET_VER
+        return LitecoinConf
 
     @staticmethod
     def ComputeAddress(pub_key, is_testnet = False):
@@ -128,6 +128,56 @@ class LitecoinHelper:
         return P2SH.ToAddress(pub_key.to_string("compressed"), addr_ver)
 
 
+class DogecoinHelper:
+    """ Bitcoin class. It contains the constants some helper methods for BIP-0049 Bitcoin. """
+
+    # Main net versions (dgub / dgpv)
+    MAIN_NET_VER = {"pub" : binascii.unhexlify(b"02facafd"), "priv" : binascii.unhexlify(b"02fac398")}
+    # Test net versions (tgub / tgpv)
+    TEST_NET_VER = {"pub" : binascii.unhexlify(b"0432a9a8"), "priv" : binascii.unhexlify(b"0432a243")}
+
+    @staticmethod
+    def GetMainNetVersions():
+        """ Get main net versions.
+
+        Returns (dict):
+            Main net versions (public at key "pub", private at key "priv")
+        """
+        return DogecoinHelper.MAIN_NET_VER
+
+    @staticmethod
+    def GetTestNetVersions():
+        """ Get test net versions.
+
+        Returns (dict):
+            Test net versions (public at key "pub", private at key "priv")
+        """
+        return DogecoinHelper.TEST_NET_VER
+
+    @staticmethod
+    def GetConfig():
+        """ Get coin configuration.
+
+        Returns (DogecoinConf):
+            Coin configuration.
+        """
+        return DogecoinConf
+
+    @staticmethod
+    def ComputeAddress(pub_key, is_testnet = False):
+        """ Get address in P2SH format.
+
+        Args:
+            pub_key (ecdsa.VerifyingKey) : ECDSA public key bytes
+            is_testnet (bool, optional)  : true if test net, false if main net (default value)
+
+        Returns (str):
+            Address string
+        """
+        addr_ver = DogecoinConf.P2SH_NET_VER["main"] if not is_testnet else DogecoinConf.P2SH_NET_VER["test"]
+        return P2SH.ToAddress(pub_key.to_string("compressed"), addr_ver)
+
+
 class DashHelper:
     """ Dash class. It contains the constants some helper methods for BIP-0049 Dash. """
 
@@ -155,13 +205,13 @@ class DashHelper:
         return DashHelper.TEST_NET_VER
 
     @staticmethod
-    def GetWifNetVersions():
-        """ Get WIF net versions.
+    def GetConfig():
+        """ Get coin configuration.
 
-        Returns (dict or None):
-            WIF net versions (main net at key "main", test net at key "test"), None if not supported
+        Returns (DashConf):
+            Coin configuration.
         """
-        return DashConf.WIF_NET_VER
+        return DashConf
 
     @staticmethod
     def ComputeAddress(pub_key, is_testnet = False):
